# solstice-libs-picker
============================================================

Library to create data driven based pickers for rigs for Solstice

.. image:: https://travis-ci.com/Solstice-Short-Film/solstice-libs-picker.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/Solstice-Short-Film/solstice-libs-picker

.. image:: https://coveralls.io/repos/github/Solstice-Short-Film/solstice-libs-picker/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/Solstice-Short-Film/solstice-libs-picker?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://solstice.github.io/solstice-libs-picker/

.. image:: https://img.shields.io/github/license/Solstice-Short-Film/solstice-libs-picker
    :target: https://github.com/Solstice-Short-Film/solstice-libs-picker/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/solstice-libs-picker?branch=master&kill_cache=1
    :target: https://pypi.org/project/solstice-libs-picker/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/

